@@ -8,7 +8,7 @@ import pandas as pd
 
 
 def generate(
-    input_signals=None, output_signals=None, include_month=False
+    input_signals=None, output_signals=None, include_month=False, path=None
 ) -> Tuple[onp.ndarray, onp.ndarray]:
     """Generate ENSO
 
@@ -33,7 +33,7 @@ def generate(
     ]
     output_signals = output_signals or ["oni"]
     data = pd.read_csv(
-        os.path.join(os.path.dirname(os.path.abspath(__file__)), "../../data/enso.csv")
+        path or os.path.join(os.path.dirname(os.path.abspath(__file__)), "../../data/enso.csv")
     )
     signal_length = data.shape[0]
 
